// Copyright 2021 iLogtail Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package helper

import (
	"github.com/alibaba/ilogtail/pkg/protocol"
	"github.com/alibaba/ilogtail/pkg/util"

	"time"
)

// LocalCollector for unit test
type LocalCollector struct {
	Logs []*protocol.Log
}

func (p *LocalCollector) AddData(tags map[string]string, fields map[string]string, t ...time.Time) {
	// log.Printf("Begin add %v %v", tags, fields)
	var logTime time.Time
	if len(t) == 0 {
		logTime = time.Now()
	} else {
		logTime = t[0]
	}
	slsLog, _ := util.CreateLog(logTime, nil, tags, fields)
	p.Logs = append(p.Logs, slsLog)
}

func (p *LocalCollector) AddDataArray(tags map[string]string,
	columns []string,
	values []string,
	t ...time.Time) {
	var logTime time.Time
	if len(t) == 0 {
		logTime = time.Now()
	} else {
		logTime = t[0]
	}
	slsLog, _ := util.CreateLogByArray(logTime, nil, tags, columns, values)
	p.Logs = append(p.Logs, slsLog)
}

func (p *LocalCollector) AddRawLog(log *protocol.Log) {
	p.Logs = append(p.Logs, log)
}
