// Copyright 2021 iLogtail Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package pluginmanager

import (
	"github.com/alibaba/ilogtail"
	"github.com/alibaba/ilogtail/pkg/logger"
	"github.com/alibaba/ilogtail/pkg/protocol"
)

type InputStatistics struct {
	context ilogtail.Context
}

func (r *InputStatistics) Init(context ilogtail.Context) (int, error) {
	r.context = context
	return 0, nil
}

func (r *InputStatistics) Description() string {
	return "statistics input plugin for logtail"
}

func (r *InputStatistics) Collect(collector ilogtail.Collector) error {
	for _, config := range LogtailConfig {
		log := &protocol.Log{}
		config.Context.MetricSerializeToPB(log)
		if len(log.Contents) > 0 && StatisticsConfig != nil {
			StatisticsConfig.LogsChan <- log
			logger.Debug(r.context.GetRuntimeContext(), "statistics", *log)
		}
	}
	return nil
}

func init() {
	ilogtail.MetricInputs["metric_statistics"] = func() ilogtail.MetricInput {
		return &InputStatistics{}
	}
}
